@@ -19,7 +19,8 @@ from aptdaemon.gtk3widgets import AptErrorDialog, AptProgressDialog
 import re
 import urllib
 
-gettext.install("pearldrivers", "/usr/share/pearllinux/locale")
+# i18n
+gettext.install("pearldrivers", "/usr/share/pearllinux/locale", names="ngettext")
 
 
 class Application():
@@ -157,23 +158,26 @@ class Application():
                     if ("README.diskdefines" in live_media):
                         mount_point = live_media.replace("/README.diskdefines", "") # This is where our live DVD is mounted
                         # Add it to apt-cdrom
-                        os.system("sudo apt-cdrom -d \"%s\" -m add" % mount_point)
-                        if ("/media/cdrom" in mount_point):
-                            mounted_on_media_cdrom = True
-            except:
-                pass
+                        p = subprocess.Popen(["sudo", "apt-cdrom", "-d", mount_point, "-m", "add"], stderr=subprocess.PIPE)
+                        (stdout, stderr) = p.communicate()
+                        mounted_on_media_cdrom = True
+                        if 'E: ' in stderr.decode():
+                           mounted_on_media_cdrom = False
+            except Exception as e:
+                print ("Exception while calling apt-cdrom:", e)
 
             if mount_point is None:
                 # Not mounted..
                 self.info_bar.show()
                 return
 
-            if mounted_on_media_cdrom == False:
+            if mounted_on_media_cdrom == False or not os.path.exists("/media/cdrom/README.diskdefines"):
                 # Mounted, but not in the right place...
                 print ("Binding mount %s to /media/cdrom" % mount_point)
                 self.clean_up_media_cdrom()
                 os.system("mkdir -p /media/cdrom")
-                os.system("mount --bind \"%s\" /media/cdrom" % mount_point)
+                p = subprocess.Popen(["mount", "--bind", mount_point, "/media/cdrom"], stderr=subprocess.PIPE)
+                stderr = p.communicate()
 
             # It should now be mounted to /media/cdrom, else something went wrong..
             if os.path.exists("/media/cdrom/README.diskdefines"):
@@ -583,7 +587,7 @@ class Application():
                     self.nonfree_drivers = self.nonfree_drivers + 1
 
         if self.nonfree_drivers > 0:
-            self.label_driver_action.set_label(gettext.ngettext(
+            self.label_driver_action.set_label(ngettext(
                 "%(count)d proprietary driver in use.",
                 "%(count)d proprietary drivers in use.",
                 self.nonfree_drivers)
@@ -592,8 +596,5 @@ class Application():
             self.label_driver_action.set_label(_("No proprietary drivers are in use."))
 
 if __name__ == "__main__":
-    if os.getuid() != 0:
-        os.execvp("gksu", ("", " ".join(sys.argv)))
-    else:
-        Application()
-        Gtk.main()
+    Application()
+    Gtk.main()
